@@ -1,7 +1,7 @@
 /*
  *  kalarmapp.h  -  the KAlarm application object
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,9 +48,19 @@ class KAlarmApp : public QApplication
 {
         Q_OBJECT
     public:
-        ~KAlarmApp();
+        ~KAlarmApp() override;
+
+        /** Create the unique instance. */
         static KAlarmApp*  create(int& argc, char** argv);
+
+        /** Must be called to complete initialisation after KAboutData is set,
+         *  but before the application is activated or restored.
+         */
+        void               initialise();
+
+        /** Return the unique instance. */
         static KAlarmApp*  instance()                      { return mInstance; }
+
         bool               checkCalendar()                 { return initCheck(); }
         bool               wantShowInSystemTray() const;
         bool               alarmsEnabled() const           { return mAlarmsEnabled; }
@@ -168,7 +178,7 @@ class KAlarmApp : public QApplication
         };
 
         KAlarmApp(int& argc, char** argv);
-        bool               initialise();
+        bool               initialiseTimerResources();
         int                activateInstance(const QStringList& args, const QString& workingDirectory, QString* outputText);
         bool               initCheck(bool calendarOnly = false, bool waitForCollection = false, Akonadi::Collection::Id = -1);
         bool               waitUntilPopulated(ResourceId, int timeout);
